@@ -41,22 +41,26 @@ class MarkdownConverter:
     def extract_filename_from_comments(content):
         """Extract filename from various comment types."""
         patterns = [
-            r'(?:^|\n)//\s*([^\n]*\.[\w]+)',  # JavaScript, C++
-            r'(?:^|\n)#\s*([^\n]*\.[\w]+)',   # Python, Bash, Ruby
-            r'/\*\s*(.*?\.[\w]+).*?\*/',       # C-style (/* */)
-            r'<!--\s*(.*?\.[\w]+).*?-->',      # HTML/XML
-            r'"""\s*(.*?\.[\w]+).*?"""',       # Python docstring
-            r"'''\s*(.*?\.[\w]+).*?'''",       # Python docstring (single quotes)
-            r'--\s*([^\n]*\.[\w]+)',          # SQL
-            r'%\s*([^\n]*\.[\w]+)',           # LaTeX
+            # Explicit filename patterns
+            r'(?:^|\n)//\s*filename:\s*([^\n]*\.[\w]+)',  # JavaScript, C++
+            r'(?:^|\n)#\s*filename:\s*([^\n]*\.[\w]+)',   # Python, Bash, Ruby
+            r'/\*\s*filename:\s*(.*?\.[\w]+).*?\*/',       # C-style (/* */)
+            r'<!--\s*filename:\s*(.*?\.[\w]+).*?-->',      # HTML/XML
+            r'"""\s*filename:\s*(.*?\.[\w]+).*?"""',       # Python docstring
+            r"'''\s*filename:\s*(.*?\.[\w]+).*?'''",       # Python docstring (single quotes)
+            r'--\s*filename:\s*([^\n]*\.[\w]+)',          # SQL
+            r'%\s*filename:\s*([^\n]*\.[\w]+)',           # LaTeX
+            # Direct filename comment patterns
+            r'(?:^|\n)//\s*([\w\-]+\.[a-zA-Z0-9]+)\s*$',  # // filename.ext
+            r'(?:^|\n)#\s*([\w\-]+\.[a-zA-Z0-9]+)\s*$',   # # filename.ext
+            r'/\*\s*([\w\-]+\.[a-zA-Z0-9]+)\s*\*/',       # /* filename.ext */
+            r'<!--\s*([\w\-]+\.[a-zA-Z0-9]+)\s*-->',      # <!-- filename.ext -->
         ]
 
         for pattern in patterns:
             match = re.search(pattern, content, re.DOTALL)
             if match:
-                filename = match.group(1).strip()
-                if '.' in filename:
-                    return filename
+                return match.group(1).strip()
 
         return None
 
@@ -68,22 +72,57 @@ class MarkdownConverter:
         files_content = {}
         file_counter = {}
 
+        # First try to extract files from non-markdown content with filename comments
+        content_parts = re.split(r'\n\s*(?://|#|/\*|\<\!--)\s*[\w\-]+\.[a-zA-Z0-9]+', markdown_content)
+        if len(content_parts) > 1:  # If we found any filename comments
+            # Reset to start of content to get the filenames too
+            current_pos = 0
+            current_file = None
+            current_content = []
+            
+            for line in markdown_content.split('\n'):
+                filename = self.extract_filename_from_comments(line)
+                if filename:
+                    if current_file:  # Save previous file content
+                        files_content[current_file] = '\n'.join(current_content).strip()
+                    current_file = filename
+                    current_content = []
+                elif current_file:  # Collect content for current file
+                    if not line.strip().startswith('//') and not line.strip().startswith('#'):
+                        current_content.append(line)
+            
+            # Save last file content
+            if current_file:
+                files_content[current_file] = '\n'.join(current_content).strip()
+
+        # Then process markdown code blocks
         for match in matches:
             language = match.group(1)
-            comment = match.group(2)
+            header = match.group(2)
             content = match.group(3).strip()
 
-            if language == 'markdown' and 'media-monitor/' in content:
+            # Skip markdown structure blocks
+            if language == 'markdown' and any(s in content for s in ['├', '└', '│']):
                 continue
 
+            # First try to get filename from the header
             filename = None
+            if header:
+                # Remove "filename:" prefix if present
+                if 'filename:' in header:
+                    filename = header.split('filename:', 1)[1].strip()
+                else:
+                    filename = header.strip()
 
-            if comment and ('.' in comment or '/' in comment):
-                filename = comment.strip()
-
+            # If no filename in header, try to get it from content comments
             if not filename:
                 filename = self.extract_filename_from_comments(content)
+                if filename:
+                    # Remove "filename:" prefix if present in extracted filename
+                    if filename.startswith('filename:'):
+                        filename = filename.split('filename:', 1)[1].strip()
 
+            # Use default patterns if no filename found
             if not filename and language:
                 language = language.lower()
                 patterns = self.config.get_file_patterns(language)
@@ -102,8 +141,10 @@ class MarkdownConverter:
                         filename = base_name
 
             if filename:
-                self.logger.debug(f"Extracted file content for: {filename}")
-                files_content[filename] = content
+                # Clean up the filename and normalize path separators
+                clean_filename = filename.strip().replace('\\', '/').lstrip('./')
+                self.logger.debug(f"Extracted file content for: {clean_filename}")
+                files_content[clean_filename] = content
 
         return files_content
 
@@ -111,16 +152,29 @@ class MarkdownConverter:
     def create_directory_structure(structure_text):
         """Create a list of paths from text directory structure."""
         paths = []
+        current_path = []
+        
         for line in structure_text.split('\n'):
             line = line.strip()
             if not line or '```' in line:
                 continue
 
+            # Count the depth by the number of │ or ├ or └ characters
+            depth = len(re.findall(r'[│├└]', line))
+            
+            # Remove tree characters and spaces
             path = re.sub(r'^[│├└─\s]+', '', line)
+            
             if path and not path.startswith('#'):
-                if not ('.' in path) and not path.endswith('/'):
-                    path += '/'
-                paths.append(path)
+                # Adjust current path based on depth
+                current_path = current_path[:depth]
+                current_path.append(path)
+                
+                # Create full path
+                full_path = '/'.join(p.rstrip('/') for p in current_path)
+                if not ('.' in path):  # It's a directory
+                    full_path += '/'
+                paths.append(full_path)
 
         return paths
 
@@ -144,23 +198,22 @@ class MarkdownConverter:
                 'conflicts': []
             }
 
-            # Check directory structure
-            structure_match = re.search(r'```markdown\n(.*?)\n```', content, re.DOTALL)
-            if structure_match:
-                paths = self.create_directory_structure(structure_match.group(1))
-                for path in paths:
-                    full_path = output_path / path
-                    if path.endswith('/'):
-                        preview_info['directories'].append({
-                            'path': str(full_path),
-                            'exists': full_path.exists()
-                        })
+            # Extract file content first to get actual files
+            files_content = self.extract_file_content(content)
+            
+            # Get directories from file paths
+            for filename in files_content.keys():
+                dir_path = os.path.dirname(filename)
+                if dir_path:
+                    full_dir_path = output_path / dir_path
+                    preview_info['directories'].append({
+                        'path': str(full_dir_path),
+                        'exists': full_dir_path.exists()
+                    })
 
             # Check files
-            files_content = self.extract_file_content(content)
-            for filename, _ in files_content.items():
-                clean_filename = filename.replace('# ', '').strip()
-                file_path = output_path / clean_filename
+            for filename in files_content.keys():
+                file_path = output_path / filename
                 preview_info['files'].append({
                     'path': str(file_path),
                     'exists': file_path.exists()
@@ -181,29 +234,9 @@ class MarkdownConverter:
             self.logger.info("Creating backup before proceeding...")
             backup_branch = self._create_backup()
             self.logger.info(f"Backup created successfully: {backup_branch}")
-            
-            # Show what was backed up
-            backup = GitBackup(self.output_dir)
-            info = backup.get_backup_info(backup_branch)
-            if info['files']:
-                self.logger.info("\nBacked up files:")
-                for file in info['files']:
-                    self.logger.info(f"- {file}")
-            else:
-                self.logger.info("No existing files were backed up")
 
         preview_info = self.preview()
         
-        # Print preview information
-        self.logger.info("\nFiles to be created:")
-        for dir_info in preview_info['directories']:
-            status = "exists" if dir_info['exists'] else "will be created"
-            self.logger.info(f"Directory: {dir_info['path']} ({status})")
-        
-        for file_info in preview_info['files']:
-            status = "exists" if file_info['exists'] else "will be created"
-            self.logger.info(f"File: {file_info['path']} ({status})")
-        
         if preview_info['conflicts'] and not force:
             self.logger.warning("\nWarning: The following files already exist:")
             for conflict in preview_info['conflicts']:
@@ -221,33 +254,21 @@ class MarkdownConverter:
             output_path = Path(self.output_dir)
             output_path.mkdir(parents=True, exist_ok=True)
 
-            structure_match = re.search(r'```markdown\n(.*?)\n```', content, re.DOTALL)
-            if structure_match:
-                paths = self.create_directory_structure(structure_match.group(1))
-                for path in paths:
-                    full_path = output_path / path
-                    if path.endswith('/'):
-                        full_path.mkdir(parents=True, exist_ok=True)
-                        self.logger.info(f"Created directory: {full_path}")
-                    else:
-                        self.ensure_directory(str(full_path))
-
             files_content = self.extract_file_content(content)
             created_files = []
 
             for filename, file_content in files_content.items():
-                clean_filename = filename.replace('# ', '').strip()
-                file_path = output_path / clean_filename
+                file_path = output_path / filename
                 self.ensure_directory(str(file_path))
 
                 self.logger.info(f"Creating file: {file_path}")
                 with open(file_path, 'w', encoding='utf-8') as f:
                     f.write(file_content + '\n')
 
-                if clean_filename.endswith('.sh'):
+                if filename.endswith('.sh'):
                     os.chmod(file_path, 0o755)
 
-                created_files.append(clean_filename)
+                created_files.append(filename)
 
             self.logger.info("\nCreated files:")
             for f in sorted(created_files):
